@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, include, url
 
 urlpatterns = patterns('',
     url(r'^acsv$', 'testing.apps.someapp.views.acsv'),
